@@ -2,6 +2,9 @@ import requests
 import time
 from PIL import Image
 
+class RateLimitError(BaseException):
+    pass
+
 class Client:
     """
     A client that does all the requests and rate limit handling for you.
@@ -37,12 +40,15 @@ class Client:
         }
         if self.get_limit == 0:
             time.sleep(self.get_timeout + 0.2)
-        with self.__http.get(self.base + "/get_pixel", headers = self.headers, params=data) as resp:
-            data = resp.json()
-            headers = resp.headers
-            self.get_limit = int(headers["requests-remaining"])
-            self.get_timeout = int(headers["requests-reset"])
-            return int(f"0x{data['rgb']}", base=16)
+        try:
+            with self.__http.get(self.base + "/get_pixel", headers = self.headers, params=data) as resp:
+                data = resp.json()
+                headers = resp.headers
+                self.get_limit = int(headers["requests-remaining"])
+                self.get_timeout = int(headers["requests-reset"])
+                return int(f"0x{data['rgb']}", base=16)
+        except KeyError:
+            raise RateLimitError("Rate limited by server but internal values not updated.")
     
     def get_canvas(self, scale=1):
         """
@@ -58,16 +64,19 @@ class Client:
             raise TypeError("Scale must be a positive integer")
         if self.gets_limit == 0:
             time.sleep(self.gets_timeout+ 0.2)
-        with self.__http.get(self.base + "/get_pixels", headers=self.headers) as resp:
-            stream = bytes(resp.content)
-            headers = resp.headers
-            self.gets_limit = int(headers["requests-remaining"])
-            self.gets_timeout = int(headers["requests-reset"])
-            with self.__http.get(self.base + "/get_size", headers= self.headers) as resps:
-                size = resps.json()
-                im =  Image.frombytes(mode="RGB", size=(size['width'], size['height']), data=stream)
-                im = im.resize((im.size[0]*scale, im.size[1]*scale), Image.NEAREST)
-                return im
+        try:
+            with self.__http.get(self.base + "/get_pixels", headers=self.headers) as resp:
+                stream = bytes(resp.content)
+                headers = resp.headers
+                self.gets_limit = int(headers["requests-remaining"])
+                self.gets_timeout = int(headers["requests-reset"])
+                with self.__http.get(self.base + "/get_size", headers= self.headers) as resps:
+                    size = resps.json()
+                    im =  Image.frombytes(mode="RGB", size=(size['width'], size['height']), data=stream)
+                    im = im.resize((im.size[0]*scale, im.size[1]*scale), Image.NEAREST)
+                    return im
+        except KeyError:
+            raise RateLimitError("Rate limited by server but internal values not updated.")
 
 
     
@@ -81,10 +90,12 @@ class Client:
         Returns:
         tuple - The width and height of the canvas
         """
-
-        with self.__http.get(self.base + "/get_size", headers=self.headers) as resp:
-            data = resp.json()
-            return (data["width"], data["height"])
+        try:
+            with self.__http.get(self.base + "/get_size", headers=self.headers) as resp:
+                data = resp.json()
+                return (data["width"], data["height"])
+        except KeyError:
+            raise RateLimitError("Rate limited by server but internal values not updated.")
 
     def set_pixel(self, x: int, y: int, color: int):
         """
@@ -105,14 +116,15 @@ class Client:
         }
         if self.post_limit == 0:
             time.sleep(self.post_timeout + 0.2)
-        with self.__http.post(self.base + "/set_pixel", headers=self.headers, json=data) as resp:
-            headers = resp.headers
-            try:
+        try:
+            with self.__http.post(self.base + "/set_pixel", headers=self.headers, json=data) as resp:
+                headers = resp.headers
                 self.post_limit = int(headers["requests-remaining"])
                 self.post_timeout = int(headers["requests-reset"])
-            except KeyError:
                 print("Rate limits without updating of internal values, aborting")
                 return
+        except KeyError:
+            raise RateLimitError("Rate limited by server but internal values not updated.")
     
     def get_limits(self):
         """
